using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using System.Runtime.InteropServices; //requirement class

namespace CShare.NET2003
{
	/// <summary>
	/// </summary>
	public class MainForm : System.Windows.Forms.Form
	{
		//1.1 SDK interface definitions.
		//==============================================================================================================
		[DllImport("pdf2image",  CallingConvention=CallingConvention.StdCall)] 
		public static extern int apOpen(string lpFileName,string lpOwnerPw,string lpUserPw);

		[DllImport("pdf2image",  CallingConvention=CallingConvention.StdCall)] 
		public static extern int apClose(int nHandle);

		[DllImport("pdf2image",  CallingConvention=CallingConvention.StdCall)] 
		public static extern int apConvert(int nHandle);

		[DllImport("pdf2image",  CallingConvention=CallingConvention.StdCall)] 
		public static extern int apConvertPage(int nHandle,int nPageNo);

		[DllImport("pdf2image",  CallingConvention=CallingConvention.StdCall)] 
		public static extern int apConvertPageToStream(int nHandle,int nPageNo,ref int pMemStream,ref int nSize);

		[DllImport("pdf2image",  CallingConvention=CallingConvention.StdCall)] 
		public static extern int apSetProperty( int    nHandle,  //Conversion object's handle.
                                                int    nIndex,   //Property tag,refer to the following property definitions.
                                                string lpValue,  //A String value of the property,(or)
                                                int    nValue,   //An integer value of the property.
                                                int    nOther);  //Only valid for progress call-back.

		[DllImport("pdf2image",  CallingConvention=CallingConvention.StdCall)] 
		public static extern int apGetProperty( int  nHandle, //Conversion object's handle.
                                                int  nIndex,  //Property tag,refer to the following property definitions.
                                                ref int pValue,     //A String value of the property,(or)
                                                ref int nValue);    //An integer value of the property.
		//==============================================================================================================

		//1.2 Definitions of converter's properties 
		//==============================================================================================================
		//read/write properties
		const int AP_PROP_OUTDIR       = 1;  //Destination directory.
		const int AP_PROP_PREFIX       = 2;  //The prefix of the name of result image file.
		const int AP_PROP_PAGEZOOM     = 3;  //Zoom scale of the source pdf page.
		const int AP_PROP_BGCOLOR      = 4;  //Image background color.
		const int AP_PROP_IMAGETYPE    = 5;  //Result image format.
		const int AP_PROP_BITCOUNT     = 6;  //Color bits per pixel.
		const int AP_PROP_XDPI         = 7;  //Horizontal resolution.
		const int AP_PROP_YDPI         = 8;  //Vertical resolution.
		const int AP_PROP_QUALITY      = 9;  //JPEG compression quality.
		const int AP_PROP_COMPRESSION  = 10; //TIFF compression mode.
		const int AP_PROP_MULTIPAGES   = 11; //Multipages TIFF file.
		const int AP_PROP_GRAYSCALE    = 12; //Grayscale image.
		const int AP_PROP_XDIMENSIONS  = 13; //The width of the result image in pixel
		const int AP_PROP_YDIMENSIONS  = 14; //The height of the result image in pixel
		const int AP_PROP_ROTATEANGLE  = 15; //Rotate angle of result image

		//read only properties
		const int AP_PROP_PAGECOUNT  = 20; //The total pages of source pdf file.
		const int AP_PROP_PAGEHEIGHT = 21; //Height of the current page of source pdf file.
		const int AP_PROP_PAGEWIDTH  = 22; //Width of the current page of source pdf file.
		//==============================================================================================================

		//1.3 TIFF tag's definitions.
		//==============================================================================================================
		const int AP_TIFF_COMPRESSION_NONE     = 0;  //No compression.
		const int AP_TIFF_COMPRESSION_LZW      = 1;  //1,4,8,24bits(default 4,8,24bits)
		const int AP_TIFF_COMPRESSION_JPEG     = 2;  //Grayscale 8bits,24bits
		const int AP_TIFF_COMPRESSION_PACKBITS = 3;  //4,8,24bits
		const int AP_TIFF_COMPRESSION_CCITTG4  = 4;  //1bit(default 1bit)
		const int AP_TIFF_COMPRESSION_CCITTG3  = 5;  //1bit
		const int AP_TIFF_COMPRESSION_RLE      = 6;  //1bit
		//==============================================================================================================

		//1.4 Image type's definitions
		//==============================================================================================================
		const int AP_IMAGE_BMP  = 1;   //BMP
		const int AP_IMAGE_EMF  = 2;   //EMF
		const int AP_IMAGE_WMF  = 3;   //WMF
		const int AP_IMAGE_JPG  = 4;   //JPG
		const int AP_IMAGE_PNG  = 5;   //PNG
		const int AP_IMAGE_GIF  = 6;   //GIF
		const int AP_IMAGE_TIF  = 7;   //TIF
		const int AP_IMAGE_PCX  = 8;   //PCX

		const int AP_IMAGE_JPEG = 4;   //JPEG
		const int AP_IMAGE_TIFF = 7;   //TIFF
		//==============================================================================================================

		//1.5 Return code's definitions.
		//==============================================================================================================
		const int RTN_OK = 1;           //Successful operation.
		const int ERR_UNKNOWN = -99;    //Unknown system error.

		const int ERR_OVER_MAXTHREADS    = -1;  //Over the limit amount of threads.
		const int ERR_FILE_UNEXIST       = -2;  //Source PDF file unexist.
		const int ERR_FILE_DAMAGED       = -3;  //Source PDF file is damaged.
		const int ERR_FILE_RESTRICTED    = -4;  //Source PDF file is restricted.

		const int ERR_INVALID_PAGE    = -5;   //The PDF page is invalid.
		const int ERR_CONVERT_FAILURE = -8;   //Conversion failure.
		const int ERR_INVALID_STREAM  = -9;   //Invalid memory stream address.
		const int ERR_INVALID_HANDLE  = -10;  //Invalid converter's handle.
		//==============================================================================================================


		//1.6 Windows API definitions.
		//==============================================================================================================
		[DllImport("kernel32.dll")] public static extern int GetTickCount();
		[DllImport("kernel32.dll")] public static extern void CopyMemory(Byte[] dest,int Source, Int32 length);

		const int TRUE = 1;
		const int FALSE = 0;
		//==============================================================================================================


		private System.Windows.Forms.Button btnDemo1;
		private System.Windows.Forms.Button btnDemo2;
		private System.Windows.Forms.Button btnDemo3;
		private System.Windows.Forms.ProgressBar m_ProgressBar;
		/// <summary>
		/// </summary>
		private System.ComponentModel.Container components = null;

		public MainForm()
		{
			InitializeComponent();
		}

		/// <summary>
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Builder Code
		/// <summary>
		/// </summary>
		private void InitializeComponent()
		{
			this.btnDemo1 = new System.Windows.Forms.Button();
			this.btnDemo2 = new System.Windows.Forms.Button();
			this.btnDemo3 = new System.Windows.Forms.Button();
			this.m_ProgressBar = new System.Windows.Forms.ProgressBar();
			this.SuspendLayout();
			// 
			// btnDemo1
			// 
			this.btnDemo1.Location = new System.Drawing.Point(24, 32);
			this.btnDemo1.Name = "btnDemo1";
			this.btnDemo1.TabIndex = 0;
			this.btnDemo1.Text = "demo1";
			this.btnDemo1.Click += new System.EventHandler(this.btnDemo1_Click);
			// 
			// btnDemo2
			// 
			this.btnDemo2.Location = new System.Drawing.Point(120, 32);
			this.btnDemo2.Name = "btnDemo2";
			this.btnDemo2.TabIndex = 1;
			this.btnDemo2.Text = "demo2";
			this.btnDemo2.Click += new System.EventHandler(this.btnDemo2_Click);
			// 
			// btnDemo3
			// 
			this.btnDemo3.Location = new System.Drawing.Point(216, 32);
			this.btnDemo3.Name = "btnDemo3";
			this.btnDemo3.TabIndex = 2;
			this.btnDemo3.Text = "demo3";
			this.btnDemo3.Click += new System.EventHandler(this.btnDemo3_Click);
			// 
			// m_ProgressBar
			// 
			this.m_ProgressBar.Location = new System.Drawing.Point(0, 108);
			this.m_ProgressBar.Name = "m_ProgressBar";
			this.m_ProgressBar.Size = new System.Drawing.Size(328, 16);
			this.m_ProgressBar.TabIndex = 3;
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(6, 14);
			this.ClientSize = new System.Drawing.Size(344, 125);
			this.Controls.Add(this.m_ProgressBar);
			this.Controls.Add(this.btnDemo3);
			this.Controls.Add(this.btnDemo2);
			this.Controls.Add(this.btnDemo1);
			this.MaximizeBox = false;
			this.Name = "MainForm";
			this.Text = "Ap pdf2image sdk demo!";
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new MainForm());
		}

		//Demo1 - Convert all pdf pages to bmp format file(s).
		private void btnDemo1_Click(object sender, System.EventArgs e)
		{
			int nHandle;
			int iStartTick,iEndTick;

			iStartTick = GetTickCount();

			//Open pdf file and creating a converter.
			nHandle = apOpen("sample.pdf","","");
			switch( nHandle ) {
				case ERR_OVER_MAXTHREADS: { MessageBox.Show("Over the limit amount of threads!"); return; }
				case ERR_FILE_UNEXIST: { MessageBox.Show("Source pdf file unexist!");  return; }
				case ERR_FILE_DAMAGED: { MessageBox.Show("Source pdf file damaged!");  return; }
				case ERR_FILE_RESTRICTED: { MessageBox.Show("Source pdf file restricted!");  return; }
			}

			//Setting the converter's propertys.
			//For more, please refer to above definitions.
			apSetProperty(nHandle,AP_PROP_OUTDIR,"./demo1",0,0);//output directory
			apSetProperty(nHandle,AP_PROP_PREFIX,"myimg",0,0);//prefix of image file name
			apSetProperty(nHandle,AP_PROP_IMAGETYPE,"",AP_IMAGE_BMP,0);//image type
			apSetProperty(nHandle,AP_PROP_XDPI,"",120,0);//horizontal dpi
			apSetProperty(nHandle,AP_PROP_YDPI,"",120,0);//vertical dpi
			//apSetProperty(nHandle,AP_PROP_ROTATEANGLE,"",75,0);//rotate angle of result image

			//Get the amount of the source pdf pages
			int pValue = 0,iPageAmount = 0;
			apGetProperty(nHandle, AP_PROP_PAGECOUNT, ref pValue, ref iPageAmount);

			//To convert the pdf file.
			for(int iPageNo = 1; iPageNo <= iPageAmount; iPageNo++)
			{
				apConvertPage(nHandle, iPageNo);

				//Setting conversion's progress.
				m_ProgressBar.Value = (int)((iPageNo * 1.0) / iPageAmount * 100);
			}

			//Close pdf file and destory the converter.
			apClose(nHandle);
			
			//To count conversion's time(ms).
			iEndTick = GetTickCount();
			MessageBox.Show("Conversion successful,it passed " + (iEndTick - iStartTick) + "ms!");
		}

		//Demo2 - Convert appointed pdf pages to tiff format file(s).
		private void btnDemo2_Click(object sender, System.EventArgs e)
		{
			int nHandle;
			int iStartTick,iEndTick;

			iStartTick = GetTickCount();

			//Open pdf file and creating a converter.
			nHandle = apOpen("sample.pdf","","");
			switch( nHandle ) 
			{
				case ERR_OVER_MAXTHREADS: { MessageBox.Show("Over the limit amount of threads!"); return; }
				case ERR_FILE_UNEXIST: { MessageBox.Show("Source pdf file unexist!");  return; }
				case ERR_FILE_DAMAGED: { MessageBox.Show("Source pdf file damaged!");  return; }
				case ERR_FILE_RESTRICTED: { MessageBox.Show("Source pdf file restricted!");  return; }
			}

			//Setting the converter's propertys.
			//For more, please refer to above definitions.
			apSetProperty(nHandle,AP_PROP_OUTDIR,"./demo2",0,0);//output directory
			apSetProperty(nHandle,AP_PROP_IMAGETYPE,"",AP_IMAGE_TIFF,0);//image type
			apSetProperty(nHandle,AP_PROP_BITCOUNT,"",24,0);//color bits
			apSetProperty(nHandle,AP_PROP_XDPI,"",150,0);//horizontal dpi
			apSetProperty(nHandle,AP_PROP_YDPI,"",150,0);//vertical dpi
			apSetProperty(nHandle,AP_PROP_COMPRESSION,"",AP_TIFF_COMPRESSION_LZW,0);//tiff compression mode
			//apSetProperty(nHandle,AP_PROP_MULTIPAGES,"",TRUE,0);//multipages tiff.

            //To convert the pdf file.
            int pValue = 0,iPageCount = 0, iPage;
			apGetProperty(nHandle, AP_PROP_PAGECOUNT, ref pValue, ref iPageCount);
            for (iPage = 1; iPage <= iPageCount; iPage++)
            {
                apConvertPage(nHandle, iPage);

				//Setting conversion's progress.
				m_ProgressBar.Value = (int)(iPage * 1.0 / iPageCount * 100);
			}

			//Close pdf file and destory the converter.
			apClose(nHandle);

			//To count conversion's time(ms).
			iEndTick = GetTickCount();
			MessageBox.Show("Conversion successful,it passed " + (iEndTick - iStartTick) + "ms!");
		}

		//demo3 - Convert appointed pdf pages to memory stream.
		private void btnDemo3_Click(object sender, System.EventArgs e)
		{
			int[] m_Pages = {1,4,7,11,20,19,13,5,6,14,8};
			int nHandle;
			int iStartTick,iEndTick;

			iStartTick = GetTickCount();

			//Open pdf file and creating a converter.
			nHandle = apOpen("sample.pdf","","");
			switch( nHandle )
			{
				case ERR_OVER_MAXTHREADS: { MessageBox.Show("Over the limit amount of threads!"); return; }
				case ERR_FILE_UNEXIST: { MessageBox.Show("Source pdf file unexist!");  return; }
				case ERR_FILE_DAMAGED: { MessageBox.Show("Source pdf file damaged!");  return; }
				case ERR_FILE_RESTRICTED: { MessageBox.Show("Source pdf file restricted!");  return; }
			}

			//Setting the converter's propertys.
			//For more, please refer to above definitions.
			apSetProperty(nHandle,AP_PROP_IMAGETYPE,"",AP_IMAGE_WMF,0);
			apSetProperty(nHandle,AP_PROP_XDIMENSIONS,"",1122,0);
			apSetProperty(nHandle,AP_PROP_YDIMENSIONS,"",1452,0);

			//To convert the appointed pages of the pdf file.
			System.IO.Directory.CreateDirectory("./demo3");
			for(int iPos = 0; iPos < m_Pages.Length; iPos++)
			{
				//You can save image stream to database, to file, or to others, etc.
				//The "pImageStream" is a pointer which point to memory image stream.
				int pImageStream = 0,nSize = 0;
				apConvertPageToStream(nHandle,m_Pages[iPos],ref pImageStream, ref nSize);

				//Here,it saves the memory image stream to bytes buffer
				byte[] bBuffer = new byte[nSize];
				CopyMemory(bBuffer,pImageStream,nSize);

				//Here,the image stream is saved to file.
				if( nSize > 0 )
				{
					string sImgFile = "./demo3/myimg_" + m_Pages[iPos] + ".wmf";
					
					System.IO.FileStream fileStream = new System.IO.FileStream(sImgFile, System.IO.FileMode.OpenOrCreate, System.IO.FileAccess.Write);
					fileStream.Write(bBuffer, 0, nSize);
					fileStream.Close();
				}

				//Setting conversion's progress.
				m_ProgressBar.Value = (int)((iPos+1)*1.0/m_Pages.Length*100);
			}

			//Close pdf file and destory the converter.
			apClose(nHandle);

			//To count conversion's time(ms).
			iEndTick = GetTickCount();
			MessageBox.Show("Conversion successful,it passed " + (iEndTick - iStartTick) + "ms!");
		}
	}
}
