unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, StdCtrls, apconvert;

type

  TMainForm = class(TForm)
    btnDemo1: TButton;
    btnDemo2: TButton;
    btnDemo3: TButton;
    m_ProgressBar: TProgressBar;
    procedure btnDemo1Click(Sender: TObject);
    procedure btnDemo2Click(Sender: TObject);
    procedure btnDemo3Click(Sender: TObject);
  private
    { Private declarations }

    //SDK interface definitions.
    //For more,please refer to "apconvert.pas"
    //---------------------------------------------------------------------------
    m_hDll: HMODULE;
    _apOpen: _FapOpen;
    _apClose: _FapClose;
    _apConvert: _FapConvert;
    _apConvertPage: _FapConvertPage;
    _apConvertPageToStream: _FapConvertPageToStream;
    _apSetProperty: _FapSetProperty;
    _apGetProperty: _FapGetProperty;

    function LoadDLL():BOOL;  //Load dynamic link library "pdf2image.dll"!
    function FreeDLL():BOOL;  //free dynamic link library "pdf2image.dll"!
    //----------------------------------------------------------------------------

  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

//Load dynamic link library---pdf2image.dll!
function TMainForm.LoadDLL():BOOL;
var
   sDllFile: PAnsiChar;
   pFunc: FARPROC;
label
   ERR_FLAG;
begin
   sDllFile := 'pdf2image.dll';
   m_hDll := LoadLibrary(sDllFile);
   if m_hDll = 0 then
   begin
      Result := FALSE;
      exit;
   end;

	 pFunc := GetProcAddress(m_hDll, 'apOpen');
	 if pFunc = nil then goto ERR_FLAG;
   _apOpen := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'apClose');
	 if pFunc = nil then goto ERR_FLAG;
   _apClose := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'apConvert');
	 if pFunc = nil then goto ERR_FLAG;
   _apConvert := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'apConvertPage');
	 if pFunc = nil then goto ERR_FLAG;
   _apConvertPage := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'apConvertPageToStream');
	 if pFunc = nil then goto ERR_FLAG;
   _apConvertPageToStream := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'apSetProperty');
	 if pFunc = nil then goto ERR_FLAG;
   _apSetProperty := pFunc;

	 pFunc := GetProcAddress(m_hDll, 'apGetProperty');
	 if pFunc = nil then goto ERR_FLAG;
   _apGetProperty := pFunc;

   Result := TRUE;
   exit;

ERR_FLAG:
   Result := FALSE;
end;

//Free dynamic link library---pdf2image.dll!
function TMainForm.FreeDLL():BOOL;
begin
	if m_hDll <> 0  then
  begin
     FreeLibrary(m_hDll);
     m_hDll := 0;
  end;
	Result := TRUE;
end;

//The progress's call-back function.
//To set conversion progress.
procedure GGetProgress(nOther:Longint;iProgress:Longint);cdecl;
var
   this: TMainForm;
begin
   this := TMainForm(nOther);
   this.m_ProgressBar.Position := iProgress;
   this.m_ProgressBar.Refresh;
end;

//Demo1 - Convert all pdf pages to bmp format file(s).
procedure TMainForm.btnDemo1Click(Sender: TObject);
var
   sPdfFile: PAnsiChar;
   nHandle: Longint;
   iStartTick,iEndTick: Longint;
begin
   sPdfFile := 'sample.pdf';

   if LoadDLL() = FALSE then
   begin
      ShowMessage('Loading dynamic link library---pdf2image.dll failure!');
      exit;
   end;

   iStartTick := GetTickCount();

   //Open pdf file and creating a converter.
   nHandle := _apOpen(sPdfFile,nil,nil);
   case nHandle of
     ERR_OVER_MAXTHREADS: begin ShowMessage('Over the limit amount of threads,please waiting!'); FreeDLL(); exit; end;
     ERR_FILE_UNEXIST: begin ShowMessage('Source pdf file unexist!'); FreeDLL(); exit; end;
     ERR_FILE_DAMAGED: begin ShowMessage('Source pdf file damaged!'); FreeDLL(); exit; end;
     ERR_FILE_RESTRICTED: begin ShowMessage('Source pdf file restricted!'); FreeDLL(); exit; end;
   end;

   //Setting the converter's propertys.
   //For more,please refer to "apconvert.pas".
   _apSetProperty(nHandle,AP_PROP_OUTDIR,'./demo1',0,0);//output directory
   _apSetProperty(nHandle,AP_PROP_PREFIX,'myimg',0,0);//prefix of image file name
   _apSetProperty(nHandle,AP_PROP_IMAGETYPE,nil,AP_IMAGE_BMP,0);//image type
   _apSetProperty(nHandle,AP_PROP_XDPI,nil,120,0);//horizontal dpi
   _apSetProperty(nHandle,AP_PROP_YDPI,nil,120,0);//vertical dpi
   //_apSetProperty(nHandle,AP_PROP_ROTATEANGLE,nil,75,0);//Rotate angle of result image

   //Setting the progress's call-back function.
   //The last parameter will be used at call-back function as a parameter value.
	 _apSetProperty(nHandle,AP_PROP_PROGRESSFUNC,nil,Longint(@GGetProgress),Longint(self));

	 //To convert the pdf file.
	 _apConvert(nHandle);

   //Close pdf file and destory the converter.
   _apClose(nHandle);

	 //To count conversion's time(ms).
	 iEndTick := GetTickCount();
   ShowMessage('Conversion successful,it passed '+IntToStr(iEndTick-iStartTick)+'ms!');

   FreeDLL();
end;

//Demo2 - Convert appointed pdf pages to tiff format file(s).
procedure TMainForm.btnDemo2Click(Sender: TObject);
var
   sPdfFile: PAnsiChar;
   nHandle: Longint;
   iPageCount,iPagei,StartTick,iEndTick: Longint;
begin
   sPdfFile := 'sample.pdf';

   if LoadDLL() = FALSE then
   begin
      ShowMessage('Loading dynamic link library---pdf2image.dll failure!');
      exit;
   end;

   iStartTick := GetTickCount();

   //Open pdf file and creating a converter.
   nHandle := _apOpen(sPdfFile,nil,nil);
   case nHandle of
     ERR_OVER_MAXTHREADS: begin ShowMessage('Over the limit amount of threads,please waiting!'); FreeDLL(); exit; end;
     ERR_FILE_UNEXIST: begin ShowMessage('Source pdf file unexist!'); FreeDLL(); exit; end;
     ERR_FILE_DAMAGED: begin ShowMessage('Source pdf file damaged!'); FreeDLL(); exit; end;
     ERR_FILE_RESTRICTED: begin ShowMessage('Source pdf file restricted!'); FreeDLL(); exit; end;
   end;

   //Setting the converter's propertys.
   //For more,please refer to header file---apconvert.pas.
   _apSetProperty(nHandle,AP_PROP_OUTDIR,'./demo2',0,0);//output directory
   _apSetProperty(nHandle,AP_PROP_IMAGETYPE,nil,AP_IMAGE_TIFF,0);//image type
   _apSetProperty(nHandle,AP_PROP_BITCOUNT,nil,24,0);//color bits
   _apSetProperty(nHandle,AP_PROP_XDPI,nil,150,0);//horizontal dpi
   _apSetProperty(nHandle,AP_PROP_YDPI,nil,150,0);//vertical dpi
   _apSetProperty(nHandle,AP_PROP_COMPRESSION,nil,AP_TIFF_COMPRESSION_LZW,0);//tiff compression mode
   //_apSetProperty(nHandle,AP_PROP_MULTIPAGES,nil,1,0);//multipages tiff.

   //To convert the pdf file.
   _apGetProperty(nHandle,AP_PROP_PAGECOUNT,nil,iPageCount)
   for iPage := 1 to iPageCount do
   begin
       _apConvertPage(nHandle,iPage);
       
       //Setting conversion's progress.
       m_ProgressBar.Position := Round(iPage*1.0/iPageCount*100);
   end;

   //Close pdf file and destory the converter.
   _apClose(nHandle);

	 //To count conversion's time(ms).
	 iEndTick := GetTickCount();
   ShowMessage('Conversion successful,it passed '+IntToStr(iEndTick-iStartTick)+'ms!');

   FreeDLL();
end;

//demo3 - Convert appointed pdf pages to memory stream.
procedure TMainForm.btnDemo3Click(Sender: TObject);
var
   sPdfFile,sImgFile: PAnsiChar;
   m_Pages: array[0..10] of Longint;
   nHandle: Longint;
   iPageCount,iStartTick,iEndTick,iPos: Longint;
   pImageStream: PByte;
   nSize: Longint;
   pFile: TFileStream;
begin
   sPdfFile := 'sample.pdf';
   m_Pages[0] := 1;    m_Pages[1] := 4;
   m_Pages[2] := 7;    m_Pages[3] := 11;
   m_Pages[4] := 20;   m_Pages[5] := 19;
   m_Pages[6] := 13;   m_Pages[7] := 5;
   m_Pages[8] := 6;    m_Pages[9] := 14;
   m_Pages[10]:= 8;

   if LoadDLL() = FALSE then
   begin
      ShowMessage('Loading dynamic link library---pdf2image.dll failure!');
      exit;
   end;

   iStartTick := GetTickCount();

   //Open pdf file and creating a converter.
   nHandle := _apOpen(sPdfFile,nil,nil);
   case nHandle of
     ERR_OVER_MAXTHREADS: begin ShowMessage('Over the limit amount of threads,please waiting!'); FreeDLL(); exit; end;
     ERR_FILE_UNEXIST: begin ShowMessage('Source pdf file unexist!'); FreeDLL(); exit; end;
     ERR_FILE_DAMAGED: begin ShowMessage('Source pdf file damaged!'); FreeDLL(); exit; end;
     ERR_FILE_RESTRICTED: begin ShowMessage('Source pdf file restricted!'); FreeDLL(); exit; end;
   end;

   //Setting the converter's propertys.
   //For more,please refer to header file---apconvert.pas.
	 _apSetProperty(nHandle,AP_PROP_IMAGETYPE,nil,AP_IMAGE_WMF,0);
	 _apSetProperty(nHandle,AP_PROP_XDIMENSIONS,nil,1122,0);
	 _apSetProperty(nHandle,AP_PROP_YDIMENSIONS,nil,1452,0);

   //To convert the appointed pages of the pdf file.
   iPageCount := 11;
   for iPos := 0 to iPageCount-1 do
   begin
       //You can save image stream to database, to file, or to others, etc.
       //The "pImageStream" is a pointer which point to memory image stream.
       _apConvertPageToStream(nHandle,m_Pages[iPos],pImageStream,nSize);

       //Here,the image stream is saved to file.
       if (pImageStream <> nil) and (nSize > 0) then
       begin
          if not DirectoryExists('demo3') then mkdir('demo3');
          sImgFile := PAnsiChar('demo3/myimg_'+IntToStr(iPos)+'.wmf');

          pFile := TFileStream.Create(sImgFile,fmCreate or fmOpenWrite);
          pFile.WriteBuffer(pImageStream^,nSize);
          pFile.Free;
       end;

		   //Setting conversion's progress.
       m_ProgressBar.Position := Round((iPos+1)*1.0/iPageCount*100);
   end;

   //Close pdf file and destory the converter.
   _apClose(nHandle);

	 //To count conversion's time(ms).
	 iEndTick := GetTickCount();
   ShowMessage('Conversion successful,it passed '+IntToStr(iEndTick-iStartTick)+'ms!');

   FreeDLL();
end;

end.
